#!/usr/bin/env ruby
#encoding: UTF-8
=begin
/***************************************************************************
 *   ©2021-2021, Michael Uplawski <michael.uplawski@uplawski.eu>           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
=end

require_relative 'logging'
class IPRange 
  extend Logging  
  @@log = init_logger(STDOUT)

  private
  
  # return ip as Integer
  def ip_to_number(ip)
    nibbles = ip.split('.')
    nibbles = nibbles.collect {|n| n.to_i}
    ( (nibbles[0] * 256 + nibbles[1] ) * 256 + nibbles[2] ) * 256 + nibbles[3]
  end

  public
  
  # check IP in range ?
  def in_range?(cip)
    (@first..@last) === ip_to_number(cip)
  end

  def irange()
    [@first, @last]
  end

  # create an IP-range
  def initialize(args) 
    @log = @@log
    if args && args.length >= 2
      
      #first IP
      @first = ip_to_number args[0]
      #last IP
      @last = ip_to_number args[1]
      if @last < @first
        @log.error('ERROR! Last IP is smaller than first. Aborting!') 
        exit false
      end
      @vrange = args[0,2] 
    end
  end

  attr_reader :vrange, :first, :last
end
######### TEST #############
if __FILE__ == $0
  rg = IPRange.new(['192.168.2.33', '192.168.255.150'])
  puts rg.first
  puts rg.last
  puts rg.in_range? '192.168.1.35' 
  puts rg.in_range? '192.168.2.35' 

  puts rg.vrange.join(' - ')
  puts rg.irange.join(' - ')
end

